@@ -340,7 +340,7 @@ func (c actionTests) actionExecMultiProfile(t *testing.T) {
 					argv: []string{"--home", "/tmp", c.env.ImagePath, "cat", "/etc/passwd"},
 					exit: 0,
 					wantOutputs: []e2e.SingularityCmdResultOp{
-						e2e.ExpectOutput(e2e.RegexMatch, `^root:x:0:0:\w*:[^:]*:/bin/ash\n`),
+						e2e.ExpectOutput(e2e.RegexMatch, `^root:x:0:0:[^:]*:[^:]*:/bin/ash\n`),
 					},
 				},
 			}
