@@ -158,7 +158,7 @@ func create(ctx context.Context, engine *EngineOperations, rpcOps *client.RPC, p
 	}
 
 	if os.Geteuid() != 0 {
-		c.sessionSize, err = safecast.ToInt(c.engine.EngineConfig.File.SessiondirMaxSize)
+		c.sessionSize, err = safecast.Convert[int](c.engine.EngineConfig.File.SessiondirMaxSize)
 		if err != nil {
 			return err
 		}
@@ -618,7 +618,7 @@ mount:
 func (c *container) mountImage(mnt *mount.Point) error {
 	var key []byte
 
-	maxDevices, err := safecast.ToInt(c.engine.EngineConfig.File.MaxLoopDevices)
+	maxDevices, err := safecast.Convert[int](c.engine.EngineConfig.File.MaxLoopDevices)
 	if err != nil {
 		return err
 	}
@@ -1146,6 +1146,25 @@ func (c *container) addKernelMount(system *mount.System) error {
 	} else {
 		sylog.Verbosef("Skipping /sys mount")
 	}
+
+	// /sys/fs/selinux must be available for opencontainers/selinux.GetEnabled() to detect SELinux.
+	if c.engine.EngineConfig.OciConfig.Process.SelinuxLabel != "" {
+		sylog.Debugf("SELinux requested, ensuring /sys/fs/selinux mount available.")
+
+		if !c.engine.EngineConfig.File.MountSys || c.engine.EngineConfig.GetNoSys() {
+			return fmt.Errorf("SELinux requested, but /sys mount disabled by configuration")
+		}
+
+		if c.userNS {
+			sylog.Debugf("/sys/fs/selinux available via /sys bind")
+		} else {
+			if err := system.Points.AddFS(mount.KernelTag, "/sys/fs/selinux", "selinuxfs", syscall.MS_NOSUID|syscall.MS_NODEV|syscall.MS_NOEXEC, ""); err != nil {
+				return fmt.Errorf("unable to add sys/fs/selinux to mount list: %s", err)
+			}
+			sylog.Verbosef("Default mount: /sys/fs/selinux")
+		}
+	}
+
 	return nil
 }
 
@@ -2636,11 +2655,11 @@ func (c *container) GetPwUID(uid uint32) (*user.User, error) {
 	if c.engine.EngineConfig.JSON.UserInfo.Username == "" {
 		return nil, osuser.UnknownUserIdError(uid)
 	}
-	uid32, err := safecast.ToUint32(c.engine.EngineConfig.JSON.UserInfo.UID)
+	uid32, err := safecast.Convert[uint32](c.engine.EngineConfig.JSON.UserInfo.UID)
 	if err != nil {
 		return nil, err
 	}
-	gid32, err := safecast.ToUint32(c.engine.EngineConfig.JSON.UserInfo.GID)
+	gid32, err := safecast.Convert[uint32](c.engine.EngineConfig.JSON.UserInfo.GID)
 	if err != nil {
 		return nil, err
 	}
