@@ -249,7 +249,7 @@ func (e *EngineOperations) prepareUserCaps(enforced bool) error {
 		}
 
 		for _, g := range groups {
-			g32, err := safecast.ToUint32(g)
+			g32, err := safecast.Convert[uint32](g)
 			if err != nil {
 				return err
 			}
@@ -360,7 +360,7 @@ func (e *EngineOperations) prepareRootCaps() error {
 		}
 
 		for _, g := range groups {
-			g32, err := safecast.ToUint32(g)
+			g32, err := safecast.Convert[uint32](g)
 			if err != nil {
 				return err
 			}
@@ -659,11 +659,11 @@ func (e *EngineOperations) prepareContainerConfig(starterConfig *starter.Config)
 			}
 		}
 
-		uid, err := safecast.ToUint32(os.Getuid())
+		uid, err := safecast.Convert[uint32](os.Getuid())
 		if err != nil {
 			return err
 		}
-		gid, err := safecast.ToUint32(os.Getgid())
+		gid, err := safecast.Convert[uint32](os.Getgid())
 		if err != nil {
 			return err
 		}
@@ -746,11 +746,11 @@ func (e *EngineOperations) prepareInstanceJoinConfig(starterConfig *starter.Conf
 		return err
 	}
 
-	uid, err := safecast.ToUint32(os.Getuid())
+	uid, err := safecast.Convert[uint32](os.Getuid())
 	if err != nil {
 		return err
 	}
-	gid, err := safecast.ToUint32(os.Getgid())
+	gid, err := safecast.Convert[uint32](os.Getgid())
 	if err != nil {
 		return err
 	}
@@ -1555,7 +1555,7 @@ func (e *EngineOperations) setUserInfo(useTargetIDs bool) error {
 	e.EngineConfig.JSON.UserInfo.Home = pw.Dir
 
 	if useTargetIDs {
-		targetUID, uidErr := safecast.ToUint32(e.EngineConfig.GetTargetUID())
+		targetUID, uidErr := safecast.Convert[uint32](e.EngineConfig.GetTargetUID())
 		if uidErr != nil {
 			return err
 		}
@@ -1586,7 +1586,7 @@ func (e *EngineOperations) setUserInfo(useTargetIDs bool) error {
 	}
 
 	for _, gid := range gids {
-		gid32, err := safecast.ToUint32(gid)
+		gid32, err := safecast.Convert[uint32](gid)
 		if err != nil {
 			return err
 		}
